<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */

namespace Hackersnews\Validator;

use User;

class UsersValidator extends Validator {

    protected $registrationRules = array(
        'username'                 => array('required', 'min:3', 'max:20', 'alpha_num', 'Unique:users'),
        'fullname'                 => array('required', 'min:3', 'max:80'),
        'gender'                   => array('required', 'in:male,female'),
        'email'                    => array('required', 'between:3,64', 'email', 'unique:users'),
        'password'                 => array('required', 'between:4,25', 'confirmed'),
        'password_confirmation'    => array('required', 'between:4,25'),
        'recaptcha_response_field' => array('required', 'recaptcha')
    );

    protected $facebookRegistrationRules = array(
        'username'              => array('required', 'min:3', 'max:20', 'alpha_num', 'unique:users'),
        'password'              => array('required', 'between:4,25', 'confirmed'),
        'password_confirmation' => array('required', 'between:4,25'),
    );

    protected $googleRegistrationRules = array(
        'username'              => array('required', 'min:3', 'max:20', 'alpha_num', 'unique:users'),
        'password'              => array('required', 'between:4,25', 'confirmed'),
        'password_confirmation' => array('required', 'between:4,25'),
    );

    protected $updateRules = array(
        'fullname' => array('required'),
        'gender'   => array('required', 'in:male,female'),
//        'dob'      => array('date_format:Y-m-d'),
        'blogurl'  => array('url'),
        'fb_link'  => array('url'),
        'tw_link'  => array('url')
    );

    protected $passwordRestRules = array(
        'email'                    => array('required', 'email'),
        'recaptcha_response_field' => array('required', 'recaptcha'),
    );

    protected $passwordUpdateRules = array(
        'password'              => array('required', 'min:6', 'confirmed'),
        'currentpassword'       => array('required'),
        'password_confirmation' => array('required', 'between:4,25')
    );

    protected $avatarUpdateRules = array(
        'avatar' => 'required|image'
    );


    public function __construct(User $model)
    {
        $this->model = $model;
    }
}