<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
Route::resource('install', 'InstallController');

// Patterns
Route::pattern('id', '[0-9]+');

// Browsing Routes
Route::get('/', array('as' => 'home', 'uses' => 'BrowseController@getTrending'));
Route::get('trending', array('as' => 'trending', 'uses' => 'BrowseController@getTrending'));
Route::get('latest', array('as' => 'latest', 'uses' => 'BrowseController@getLatest'));
Route::get('featured', array('as' => 'featured', 'uses' => 'BrowseController@getFeatured'));

// News Routes
Route::get('news/trending', array('as' => 'news-trending', 'uses' => 'NewsController@getTrending'));
Route::get('news/latest', array('as' => 'news-latest', 'uses' => 'NewsController@getLatest'));
Route::get('news/featured', array('as' => 'news-featured', 'uses' => 'NewsController@getFeatured'));

// Questions Routes
Route::get('questions/trending', array('as' => 'questions-trending', 'uses' => 'QuestionsController@getTrending'));
Route::get('questions/latest', array('as' => 'questions-latest', 'uses' => 'QuestionsController@getLatest'));
Route::get('questions/latest', 'QuestionsController@getLatest'); // Alias for questions latest
Route::get('questions/featured', array('as' => 'questions-featured', 'uses' => 'QuestionsController@getFeatured'));

Route::get('rss', array('as' => 'rss', 'uses' => 'RssController@getRss'));
/**
 * Guest only visit this section
 */
Route::group(array('before' => 'guest'), function ()
{
    Route::get('login', array('as' => 'login', 'uses' => 'LoginController@index'));
    // Facebook
    Route::get('get/facebook', 'LoginController@loginWithFacebook');
    Route::get('registration/facebook', 'RegistrationController@getFacebook');
    // Google
    Route::get("get/google", 'LoginController@loginWithGoogle');
    Route::get("registration/google", 'RegistrationController@getGoogle');

    Route::controller('password', 'RemindersController');
    Route::get('registration', array('as' => 'registration', 'uses' => 'RegistrationController@getIndex'));
    Route::get('registration/activate/{username}/{code}', 'RegistrationController@validateUser');
});
/**
 * Guest routes require csrf protection
 */
Route::group(array('before' => 'guest|csrf'), function ()
{
    Route::post('login', 'LoginController@postLogin');
    // Facebook
    Route::post('registration/facebook', 'RegistrationController@postFacebook');
    // Google
    Route::post('registration/google', 'RegistrationController@postGoogle');
    // Normal Registration
    Route::post('registration', 'RegistrationController@postIndex');
    Route::post('password/remind', 'PasswordresetController@postIndex');
    Route::post('password/reset/{token}', 'PasswordresetController@resetPassword');
});

// Group routes ( Require Login )
Route::group(array('before' => 'auth'), function ()
{
    Route::get('news/submit', array('as' => 'news-submit', 'uses' => 'NewsController@index'))->before('ban');
    Route::post('news/submit', 'NewsController@create')->before('csrf|ban');
    Route::post('vote', 'NewsController@vote');

    Route::get('question/submit', array('as' => 'question-submit', 'uses' => 'QuestionsController@index'))->before('ban');
    Route::post('question/submit', 'QuestionsController@create')->before('csrf|ban');

    Route::post('comment/{id}-{slug?}', array('as' => 'post-comment', 'uses' => 'CommentsController@create'))->before('csrf|ban');
    Route::post('reply', 'ReplyController@create');
    //Settings
    Route::get('settings', array('as' => 'settings', 'uses' => 'UsersController@getSettings'));
    Route::post('settings/profile', 'UsersController@updateProfile')->before('csrf');
    Route::post('settings/email', 'UsersController@updateProfile')->before('csrf');
    Route::post('settings/mailsettings', 'UsersController@mailSettings')->before('csrf');
    Route::post('settings/changepassword', 'UsersController@changePassword')->before('csrf');
    Route::post('settings/avatar', 'UsersController@updateAvatar')->before('csrf');

    // Logout
    Route::get('logout', array('as' => 'logout', 'uses' => 'LoginController@destroy'));

    // Flags Route
    Route::get('flag/{id}', array('as' => 'flag', 'uses' => 'FlagsController@getIndex'));
    Route::post('flag/{id}', 'FlagsController@postReport')->before('csrf|ban');
    Route::get('flag/user/{username}', array('as' => 'flag-user', 'uses' => 'FlagsController@getUserIndex'));
    Route::post('flag/user/{username}', 'FlagsController@postUserReport')->before('csrf|ban');

    // Notification
    Route::get('notifications', array('as' => 'notifications', 'uses' => 'UsersController@getNotifications'));
});

// News
Route::get('news', 'NewsController@getLatest'); // Alias for news latest
Route::get('news/{id}-{slug?}', array('as' => 'news', 'uses' => 'NewsController@show'));
Route::get('news/{id}-{slug?}/edit', array('as' => 'news-edit', 'uses' => 'NewsController@edit'))->before('auth');
Route::post('news/{id}-{slug?}/edit', array('as' => 'news-edit', 'uses' => 'NewsController@postEdit'))->before('auth|csrf');
// Questions.
Route::get('questions', array('as' => 'questions', 'uses' => 'QuestionsController@getLatest')); // Alias for questions latest
Route::get('question/{id}-{slug?}', array('as' => 'question', 'uses' => 'QuestionsController@get'));
Route::get('question/{id}-{slug?}/edit', array('as' => 'question-edit', 'uses' => 'QuestionsController@edit'))->before('auth');
Route::post('question/{id}-{slug?}/edit', array('as' => 'question-edit', 'uses' => 'QuestionsController@postEdit'))->before('auth|csrf');

// User
Route::get('user/{username}', array('as' => 'user', 'uses' => 'UsersController@getUser'));

// Blogs
Route::get('blogs', array('as' => 'blogs', 'uses' => 'BlogsController@getIndex'));
Route::get('blog/{id}/{slug}', array('as' => 'blog', 'uses' => 'BlogsController@getBlog'));

// Search
Route::get('search', array('as' => 'serach', 'uses' => 'SearchController@search'));

// Policy
Route::get('tos', array('as' => 'tos', 'uses' => 'PolicyController@getTos'));
Route::get('privacy', array('as' => 'privacy', 'uses' => 'PolicyController@getPrivacy'));
Route::get('faq', array('as' => 'faq', 'uses' => 'PolicyController@getFaq'));
Route::get('about', array('as' => 'about', 'uses' => 'PolicyController@getAbout'));

// Language route
Route::get('lang/{lang?}', function ($lang)
{
    if (in_array($lang, languageArray()))
    {
        Session::put('my.locale', $lang);
    }
    else
    {
        Session::put('my.locale', 'en');
    }

    return Redirect::to('/');
});


// Follow Un protection is from controller
Route::group(array('before' => 'ajax|ajaxban'), function ()
{
    Route::post('follow', 'FollowController@follow');
    Route::post('deletecomment', 'CommentsController@delete');
    Route::post('votecomment', 'CommentsController@vote');
    Route::post('votereply', 'ReplyController@vote');
    Route::post('deletereply', 'ReplyController@delete');
});

/**
 * Admin section users with admin privileges can access this area
 */
Route::group(array('before' => 'admin', 'namespace' => 'Controllers\Admin'), function ()
{
    Route::get('admin', 'IndexController@getIndex');

// Users Manager
    Route::get('admin/users', 'Users\UsersController@getUsersList');
    Route::get('admin/users/featured', 'Users\UsersController@getFeaturedUserList');
    Route::get('admin/users/banned', 'Users\UsersController@getBannedUserList');
    Route::get('admin/user/{username}/edit', 'Users\UsersController@getEditUser');
    Route::get('admin/adduser', 'Users\UsersController@getAddUser');
    Route::post('admin/user/{username}/edit', 'Users\UpdateController@updateUser');
    Route::post('admin/adduser', 'Users\UpdateController@addUser');

// News Manger
    Route::get('admin/news', 'News\NewsController@getAll');
    Route::get('admin/news/featured', 'News\NewsController@getFeatured');
    Route::get('admin/news/approval', 'News\NewsController@getApprovalRequired');
    Route::get('admin/news/{id}/edit', 'News\NewsController@getEdit');
    Route::post('admin/news/{id}/edit', 'News\NewsController@update');
    Route::post('admin/images/approve', 'Images\UpdateController@postApprove');
    Route::post('admin/images/disapprove', 'Images\UpdateController@postDisapprove');

// Questions Manger
    Route::get('admin/questions', 'Questions\QuestionsController@getAll');
    Route::get('admin/questions/featured', 'Questions\QuestionsController@getFeatured');
    Route::get('admin/questions/approval', 'Questions\QuestionsController@getApprovalRequired');
    Route::get('admin/question/{id}/edit', 'Questions\QuestionsController@getEdit');
    Route::post('admin/question/{id}/edit', 'Questions\QuestionsController@update');
    Route::post('admin/question/approve', 'Images\QuestionsController@postApprove');
    Route::post('admin/question/disapprove', 'Images\QuestionsController@postDisapprove');

// Site Settings
    Route::get('admin/sitesettings', 'SiteSettings\SettingsController@getSiteDetails');
    Route::get('admin/sitecategory', 'SiteSettings\SettingsController@getSiteCategory');
    Route::get('admin/limitsettings', 'SiteSettings\SettingsController@getLimitSettings');
    Route::get('admin/removecache', 'SiteSettings\SettingsController@getRemoveCache');
    Route::get('admin/updatesitemap', 'SiteSettings\UpdateController@updateSiteMap');
    Route::post('admin/sitesettings', 'SiteSettings\UpdateController@updateSettings');
    Route::post('admin/limitsettings', 'SiteSettings\UpdateController@postLimitSettings');
    Route::post('admin/sitecategory', 'SiteSettings\UpdateController@createSiteCategory');
    Route::post('admin/sitecategory/reorder', 'SiteSettings\UpdateController@reorderSiteCategory');
    Route::post('admin/sitecategory/update', 'SiteSettings\UpdateController@updateSiteCategory');

// Comments ( done )
    Route::get('admin/comments', 'Comments\CommentsController@getComments');
    Route::get('admin/comment/{id}/edit', 'Comments\CommentsController@getEditComment');
    Route::post('admin/comment/{id}/edit', 'Comments\CommentsController@postEditComment');


// Blogs
    Route::get('admin/blogs', 'Blogs\BlogsController@getBlogs');
    Route::get('admin/blog/create', 'Blogs\BlogsController@getCreate');
    Route::get('admin/blog/{id}/edit', 'Blogs\BlogsController@getEdit');
    Route::post('admin/blog/create', 'Blogs\BlogsController@postCreate');
    Route::post('admin/blog/{id}/edit', 'Blogs\BlogsController@postEdit');

//Bulk upload
    Route::get('admin/bulkupload', 'Bulkupload\BulkuploadController@getBulkUpload');
    Route::post('admin/bulkupload', 'Bulkupload\BulkuploadController@postBulkUpload');

// Reports
    Route::get('admin/reports', 'Reports\ReportsController@getReports');
    Route::get('admin/report/{id}', 'Reports\ReportsController@getReadReport');

});