@extends('master/index')
@section('meta_title')
{{ ucfirst($user->fullname) }}'s Profile - {{ siteSettings('siteName') }}
@stop
@section('page-content')
<div class="row">
    <h1 class="page-header">{{ ucfirst($user->fullname) }} &nbsp;
        <small>{{{ $user->username }}}</small>
    </h1>
</div>

<div class="col-md-3 col-sm-12 col-xs-12">
    <a href="{{ route('user', array('username' => $user->username)) }}" class="pull-left user-profile-picture">
        <img src="{{ getAvatar($user,55) }}" class="img img-circle">
    </a>
    <h4>{{{ $user->fullname }}}<br>
        <small>{{{ $user->username }}}</small>
    </h4>
    <hr class="hidden-lg hidden-md"/>
</div>

<div class="col-md-3">
    <ul class="list-unstyled">
        <li></li>
        <li class="fa fa-check-circle-o fa-fw"></li>
        {{ $user->posts()->sum('views') }} {{ t('Views') }}
        <li></li>
        <li class="fa fa-chevron-circle-up fa-fw"></li>
        {{ $user->votes->count() }} {{ t('Post Voted') }}
        <li></li>
        <li class="fa fa-eye fa-fw"></li>
        {{ $user->posts->count() }} {{ t('Posts') }}
        <li></li>
        <li class="fa fa-comments-o fa-fw"></li>
        {{ $user->comments->count() }} {{ t('Comments') }}
    </ul>
    <hr class="hidden-lg hidden-md"/>
</div>

@if($user->fb_link || $user->tw_link || $user->blogurl)
<div class="col-md-3">
    <ul class="list-unstyled user-social">
        @if($user->fb_link)
        <li></li>
        <li class="fa fa-facebook fa-fw"></li>
        <a href="{{ addhttp($user->fb_link) }}">{{ t('Facebook Profile') }}</a>
        @endif
        @if($user->tw_link)
        <li></li>
        <li class="fa fa-twitter fa-fw"></li>
        <a href="{{ addhttp($user->tw_link) }}">{{ t('Twitter Profile') }}</a>
        @endif
        @if($user->blogurl)
        <li></li>
        <li class="fa fa-link fa-fw"></li>
        <a href="{{ addhttp($user->blogurl) }}">{{ t('Blog Url') }}</a>
        @endif
    </ul>
    <hr class="hidden-lg hidden-md"/>
</div>
@endif
@if(Auth::check())
@if(Auth::user()->id !== $user->id)
<div class="col-md-3">
    <p>{{ $user->followers->count() }} {{ t('Followers') }}</p>
    @if(Auth::user()->following()->whereFollowId($user->id)->count() < 1)
    <button class="btn btn-info follow" data-id="{{ $user->id }}">{{ t('Follow Me') }}</button>
    @else
    <button class="btn btn-danger follow" data-id="{{ $user->id }}">{{ t('Un Follow') }}</button>
    @endif
</div>
@endif
@endif

<div class="clearfix"></div>
<hr/>
@foreach($posts as $post)
<div class="row post-item post-{{ $post->type }}" id="{{ $post->id }}">
    <div class="col-lg-1 col-md-1 col-sm-2 col-xs-2 up-vote">
        <ul class="list-unstyled text-center">
            @if(Auth::user())
            @if(checkVoted($post->votes))
            <li class="up-vote-icon"><i class="fa fa-chevron-circle-up vote-btn voted" data-id="{{ $post->id }}"></i></li>
            @else
            <li class="up-vote-icon"><i class="fa fa-chevron-circle-up vote-btn" data-id="{{ $post->id }}"></i></li>
            @endif
            <li><span id="data-number-{{ $post->id }}">{{ $post->votes->count() }}</span></li>
            @else
            <li class="up-vote-icon"><a href="{{ route('login') }}"><i class="fa fa-chevron-circle-up" data-id="{{ $post->id }}"></i></a></li>
            <li><span id="data-number-{{ $post->id }}">{{ $post->votes->count() }}</span></li>
            @endif
        </ul>
    </div>
    <div class="col-lg-10 col-md-9 col-sm-10 col-xs-10">
        @if($post->type == 'news')
        <h2 class="post-title">{{ link_to(filter_var($post->url,FILTER_SANITIZE_URL), ucfirst(e($post->title)), array('target'=>'_blank','rel'=>'nofollow')) }}&nbsp;
            <small>{{ parseUrl($post->url) }}</small>
        </h2>
        @else
        <h2 class="post-title">{{ link_to_route($post->type, ucfirst(e($post->title)), array('id' => $post->id, 'slug'=> $post->slug), array('target'=>'_blank')) }}</h2>
        @endif

        <p><abbr class="timeago" title="{{ $post->created_at->toISO8601String() }}">{{ $post->created_at->toDateTimeString() }}</abbr> in {{ link_to_route('latest', $post->category->name, array('category'=>$post->category->slug)) }} {{ t('by')}} {{ link_to_route('user',ucfirst($post->user->fullname), array('username'=>$post->user->username)) }}</p>

        <ul class="list-inline">
            <li><i class="fa fa-comments-o"></i>&nbsp;{{ link_to_route($post->type, $post->comments->count() . '&nbsp;'. t('comments'),array('id'=>$post->id,'slug'=>$post->slug)) }}</li>
            <li><i class="fa fa-eye"></i>&nbsp;{{ $post->views }}&nbsp;{{ t('views') }}</li>
            <li><i class="fa fa-flag-o flag"></i>&nbsp;{{ link_to_route('flag', t('Flag'), array('id'=>$post->id), array('class' => 'flag')) }}</li>
        </ul>

    </div>
    <!--/.col-lg-9 col-md-9 col-sm-9 col-xs-9-->
    <div class="col-lg-1 col-md-2 hidden-sm hidden-xs">
        <a href="{{ route('user',$post->user->username) }}"><img src="{{ getAvatar($post->user) }}" class="img-circle"/></a>
    </div>
    <!--/.col-md-1 col-lg-1 hidden-sm hidden-xs-->
</div>
@endforeach
<p><i class="fa fa-flag-o flag"></i> {{ link_to_route('flag-user',t('Flag'),array('username'=>$user->username),array('class'=>'flag')) }}</p>
@stop

@section('pagination')
{{ $posts->links() }}
@stop